@@ -13,27 +13,27 @@
 //! ## High level workflow
 //!
 //! 1. Create new rust project (via `cargo new` or similar) at path `$PROJ_PATH`
-//! 1. Create directory `$PROJ_PATH/src/bpf`
-//! 1. Write CO-RE bpf code in `$PROJ_PATH/src/bpf/${MYFILE}.bpf.c`, where `$MYFILE` may be any
+//! 2. Create directory `$PROJ_PATH/src/bpf`
+//! 3. Write CO-RE bpf code in `$PROJ_PATH/src/bpf/${MYFILE}.bpf.c`, where `$MYFILE` may be any
 //!    valid filename. Note the `.bpf.c` extension is required.
-//! 1. Create a [build script](https://doc.rust-lang.org/cargo/reference/build-scripts.html)
+//! 4. Create a [build script](https://doc.rust-lang.org/cargo/reference/build-scripts.html)
 //!    that builds and generates a skeleton module using `libbpf_cargo::SkeletonBuilder`
-//! 1. Write your userspace code by importing and using the generated module. Import the
+//! 5. Write your userspace code by importing and using the generated module. Import the
 //!    module by using the [path
 //!    attribute](https://doc.rust-lang.org/reference/items/modules.html#the-path-attribute).
 //!    Your userspace code goes in `$PROJ_PATH/src/` as it would in a normal rust project.
-//! 1. Continue regular rust workflow (ie `cargo build`, `cargo run`, etc)
+//! 6. Continue regular rust workflow (ie `cargo build`, `cargo run`, etc)
 //!
 //! ## Alternate workflow
 //!
 //! While using the skeleton is recommended, it is also possible to directly use libbpf-rs.
 //!
 //! 1. Follow steps 1-3 of "High level workflow"
-//! 1. Generate a BPF object file. Options include manually invoking `clang`, creating a build
+//! 2. Generate a BPF object file. Options include manually invoking `clang`, creating a build
 //!    script to invoke `clang`, or using `libbpf-cargo` cargo plugins.
-//! 1. Write your userspace code in `$PROJ_PATH/src/` as you would a normal rust project and point
+//! 3. Write your userspace code in `$PROJ_PATH/src/` as you would a normal rust project and point
 //!    libbpf-rs at your BPF object file
-//! 1. Continue regular rust workflow (ie `cargo build`, `cargo run`, etc)
+//! 4. Continue regular rust workflow (ie `cargo build`, `cargo run`, etc)
 //!
 //! ## Design
 //!
@@ -92,6 +92,7 @@ pub mod query;
 mod ringbuf;
 mod skeleton;
 mod tc;
+mod user_ringbuf;
 mod util;
 mod xdp;
 
@@ -144,6 +145,8 @@ pub use crate::tc::TC_H_INGRESS;
 pub use crate::tc::TC_H_MIN_EGRESS;
 pub use crate::tc::TC_H_MIN_INGRESS;
 pub use crate::tc::TC_INGRESS;
+pub use crate::user_ringbuf::UserRingBuffer;
+pub use crate::user_ringbuf::UserRingBufferSample;
 pub use crate::util::num_possible_cpus;
 pub use crate::xdp::Xdp;
 pub use crate::xdp::XdpFlags;
