@@ -13,17 +13,12 @@ use std::mem::size_of;
 use std::os::unix::io::AsFd;
 use std::path::Path;
 use std::path::PathBuf;
+use std::ptr;
 use std::ptr::addr_of;
 use std::slice;
 use std::sync::mpsc::channel;
 use std::time::Duration;
 
-use plain::Plain;
-use probe::probe;
-use scopeguard::defer;
-use std::ptr;
-use tempfile::NamedTempFile;
-
 use libbpf_rs::num_possible_cpus;
 use libbpf_rs::AsRawLibbpf;
 use libbpf_rs::Iter;
@@ -42,6 +37,11 @@ use libbpf_rs::ProgramType;
 use libbpf_rs::TracepointOpts;
 use libbpf_rs::UprobeOpts;
 use libbpf_rs::UsdtOpts;
+use libbpf_rs::UserRingBuffer;
+use plain::Plain;
+use probe::probe;
+use scopeguard::defer;
+use tempfile::NamedTempFile;
 
 fn get_test_object_path(filename: &str) -> PathBuf {
     let mut path = PathBuf::new();
@@ -528,6 +528,58 @@ fn test_sudo_object_map_queue_crud() {
         .is_none());
 }
 
+/// Test CRUD operations on map of type bloomfilter.
+#[test]
+fn test_sudo_object_map_bloom_filter_crud() {
+    bump_rlimit_mlock();
+
+    let obj = get_test_object("tracepoint.bpf.o");
+    let bloom_filter = obj
+        .map("bloom_filter")
+        .expect("failed to find bloom_filter map");
+
+    let key: [u8; 0] = [];
+    let value1 = 1337u32.to_ne_bytes();
+    let value2 = 2674u32.to_ne_bytes();
+
+    bloom_filter
+        .update(&key, &value1, MapFlags::ANY)
+        .expect("failed to add entry value1 to bloom filter");
+
+    bloom_filter
+        .update(&key, &value2, MapFlags::ANY)
+        .expect("failed to add entry value2 in bloom filter");
+
+    // Non empty keys should result in an error
+    bloom_filter
+        .update(&value1, &value1, MapFlags::ANY)
+        .expect_err("Non empty key should return an error");
+
+    for inserted_value in [value1, value2] {
+        let val = bloom_filter
+            .lookup_bloom_filter(&inserted_value)
+            .expect("failed retrieve item from bloom filter");
+
+        assert!(val);
+    }
+    // Test non existing element
+    let enoent_found = bloom_filter
+        .lookup_bloom_filter(&[1, 2, 3, 4])
+        .expect("failed retrieve item from bloom filter");
+
+    assert!(!enoent_found);
+
+    // Calling lookup should result in an error
+    bloom_filter
+        .lookup(&[1, 2, 3, 4], MapFlags::ANY)
+        .expect_err("lookup should fail since we should use lookup_bloom_filter");
+
+    // Deleting should not be possible
+    bloom_filter
+        .lookup_and_delete(&key)
+        .expect_err("Expect delete to fail");
+}
+
 /// Test CRUD operations on map of type stack.
 #[test]
 fn test_sudo_object_map_stack_crud() {
@@ -551,6 +603,7 @@ fn test_sudo_object_map_stack_crud() {
         .lookup(&key, MapFlags::ANY)
         .expect("failed to pop from stack")
         .expect("failed to retrieve value");
+
     assert_eq!(val.len(), 4);
     assert_eq!(&val, &value2);
 
@@ -1192,6 +1245,102 @@ fn test_sudo_object_ringbuf_with_closed_map() {
     });
 }
 
+#[test]
+fn test_sudo_object_user_ringbuf() {
+    #[repr(C)]
+    struct MyStruct {
+        key: u32,
+        value: u32,
+    }
+
+    unsafe impl Plain for MyStruct {}
+
+    bump_rlimit_mlock();
+
+    let mut obj = get_test_object("user_ringbuf.bpf.o");
+    let prog = obj
+        .prog_mut("handle__sys_enter_getpid")
+        .expect("failed to find program");
+    let _link = prog.attach().expect("failed to attach prog");
+    let urb_map = obj
+        .map("user_ringbuf")
+        .expect("failed to find user ringbuf map");
+    let user_ringbuf = UserRingBuffer::new(urb_map).expect("failed to create user ringbuf");
+    let mut urb_sample = user_ringbuf
+        .reserve(size_of::<MyStruct>())
+        .expect("failed to reserve space");
+    let bytes = urb_sample.as_mut();
+    let my_struct = plain::from_mut_bytes::<MyStruct>(bytes).expect("failed to convert bytes");
+    my_struct.key = 42;
+    my_struct.value = 1337;
+    user_ringbuf
+        .submit(urb_sample)
+        .expect("failed to submit sample");
+
+    // Trigger BPF program.
+    let _pid = unsafe { libc::getpid() };
+
+    // At this point, the BPF program should have run and consumed the sample in
+    // the user ring buffer, and stored the key/value in the samples map.
+    let samples_map = obj.map("samples").expect("failed to find map");
+    let key: u32 = 42;
+    let value: u32 = 1337;
+    let res = samples_map
+        .lookup(&key.to_ne_bytes(), MapFlags::ANY)
+        .expect("failed to lookup")
+        .expect("failed to find value for key");
+
+    // The value in the samples map should be the same as the value we submitted
+    assert_eq!(res.len(), size_of::<u32>());
+    let mut array = [0; size_of::<u32>()];
+    array.copy_from_slice(&res[..]);
+    assert_eq!(u32::from_ne_bytes(array), value);
+}
+
+#[test]
+fn test_sudo_object_user_ringbuf_reservation_too_big() {
+    bump_rlimit_mlock();
+
+    let mut obj = get_test_object("user_ringbuf.bpf.o");
+    let prog = obj
+        .prog_mut("handle__sys_enter_getpid")
+        .expect("failed to find program");
+    let _link = prog.attach().expect("failed to attach prog");
+    let urb_map = obj
+        .map("user_ringbuf")
+        .expect("failed to find user ringbuf map");
+    let user_ringbuf = UserRingBuffer::new(urb_map).expect("failed to create user ringbuf");
+    let err = user_ringbuf.reserve(1024 * 1024).unwrap_err();
+    assert!(
+        err.to_string().contains("requested size is too large"),
+        "{err:#}"
+    );
+}
+
+#[test]
+fn test_sudo_object_user_ringbuf_not_enough_space() {
+    bump_rlimit_mlock();
+
+    let mut obj = get_test_object("user_ringbuf.bpf.o");
+    let prog = obj
+        .prog_mut("handle__sys_enter_getpid")
+        .expect("failed to find program");
+    let _link = prog.attach().expect("failed to attach prog");
+    let urb_map = obj
+        .map("user_ringbuf")
+        .expect("failed to find user ringbuf map");
+    let user_ringbuf = UserRingBuffer::new(urb_map).expect("failed to create user ringbuf");
+    let _ = user_ringbuf
+        .reserve(1024 * 3)
+        .expect("failed to reserve space");
+    let err = user_ringbuf.reserve(1024 * 3).unwrap_err();
+    assert!(
+        err.to_string()
+            .contains("not enough space in the ring buffer"),
+        "{err:#}"
+    );
+}
+
 #[test]
 fn test_sudo_object_task_iter() {
     bump_rlimit_mlock();
